﻿using System;
using System.Collections.Specialized;
using System.Linq;
using System.Text;
using System.Web;
using System.Web.UI;

using Sitecore;
using Sitecore.Data;
using Sitecore.Data.Items;
using Sitecore.Shell.Applications.WebEdit;
using Sitecore.Shell.Framework.Commands;
using Sitecore.Text;
using Sitecore.Web.UI.Sheer;

namespace Kevin
{
    /// <summary>
    /// Handles the example:MetadataButton command.
    /// </summary>
    public class MetadataButton : Command
    {
        public override void Execute(CommandContext context)
        {
            if (context.Items.Length < 1) return;

            // Start the field editor.
            ClientPipelineArgs args = new ClientPipelineArgs(context.Parameters);
            args.Parameters.Add("uri", context.Items[0].Uri.ToString());
            args.Parameters.Add("command", "/sitecore/content/Applications/WebEdit/Edit Frame Buttons/Default/Edit");
            Context.ClientPage.Start(this, "StartFieldEditor", args);
        }

        protected void StartFieldEditor(ClientPipelineArgs args)
        {
            HttpContext current = HttpContext.Current;
            if (current != null)
            {
                Page handler = current.Handler as Page;
                if (handler != null)
                {
                    NameValueCollection form = handler.Request.Form;
                    if (form != null)
                    {
                        // If not postback, show the field editor.
                        if (!args.IsPostBack)
                        {
                            // Get the item.
                            Item item = Database.GetItem(ItemUri.Parse(args.Parameters["uri"]));

                            // Get the field descriptor objects.
                            ListString fieldNames = new ListString("Title|Meta Description|Meta Keywords");
                            var fields = fieldNames.Select(f => new FieldDescriptor(item, f));

                            // Set the field editor options.
                            PageEditFieldEditorOptions options = new PageEditFieldEditorOptions(form, fields)
                            {
                                Title = "Edit Metadata",
                                Icon = string.Empty
                            };

                            // Show the dialog.
                            SheerResponse.ShowModalDialog(options.ToUrlString().ToString(), "720", "520", string.Empty, true);
                            args.WaitForPostBack();
                        }
                        else if (args.HasResult)
                        {
                            // If this IS a postback, parse the results from the field editor and set values.
                            PageEditFieldEditorOptions.Parse(args.Result).SetPageEditorFieldValues();
                        }
                    }
                }
            }
        }
    }
}
